==> core-components-pattern-lock-v1-1.1.9.tgz: package/modern/components/base-pattern-lock/Component.js <==
import React, { forwardRef, useState, useEffect } from 'react';
import { ReactCanvasPatternLock } from 'react-canvas-pattern-lock';
import cn from 'classnames';
import { ButtonMobile } from '@alfalab/core-components-button/modern/mobile';
import { getDataTestId } from '@alfalab/core-components-shared/modern';
import { THEME_STATE, DEFAULT_EXTRA_BOUNDS, OBSERVE_OPTIONS, OBSERVABLE_TOKENS } from '../../consts.js';
import { getSizes, getTheme, getColorByToken, getDefaultObserveTarget } from '../../utils.js';

const commonStyles = {"component":"pattern-lock-v1__component_swbrl","hidden":"pattern-lock-v1__hidden_swbrl","message":"pattern-lock-v1__message_swbrl","error":"pattern-lock-v1__error_swbrl","forgotBtn":"pattern-lock-v1__forgotBtn_swbrl"};
require('./index.css')

const BasePatternLock = forwardRef(({ observeTokens = false, observerParams = {}, justifyNodes = 'space-between', className, error, dataTestId, forgotCodeBtnText = 'Забыли код?', showForgotCodeBtn = false, onForgotBtnClick, extraBounds = DEFAULT_EXTRA_BOUNDS, message, messageClassName, hover, styles = {}, ...restProps }, ref) => {
    const [params, setParams] = useState();
    useEffect(() => {
        const { elementSizes, width, height } = getSizes();
        setParams({
            theme: getTheme(elementSizes),
            width,
            height,
        });
    }, []);
    useEffect(() => {
        let styleObserver = null;
        if (observeTokens) {
            const { options = OBSERVE_OPTIONS, getTarget = getDefaultObserveTarget } = observerParams;
            styleObserver = new MutationObserver(() => setParams((prevState) => {
                const { width, height, elementSizes } = getSizes();
                if (!prevState) {
                    return { theme: getTheme(elementSizes), width, height };
                }
                const prevBgColor = prevState.theme[THEME_STATE.INITIAL].colors.bg;
                const themeChanged = prevBgColor !== getColorByToken(OBSERVABLE_TOKENS.BG);
                if (themeChanged)
                    return { ...prevState, theme: getTheme(elementSizes) };
                return prevState;
            }));
            styleObserver.observe(getTarget(), options);
        }
        return () => styleObserver?.disconnect();
        // eslint-disable-next-line react-hooks/exhaustive-deps
    }, [observeTokens]);
    const renderMessage = () => (React.createElement("div", { className: cn(commonStyles.message, messageClassName), "data-test-id": getDataTestId(dataTestId, 'message') }, message));
    const renderError = () => (React.createElement("div", { className: cn(commonStyles.message, commonStyles.error, messageClassName), "data-test-id": getDataTestId(dataTestId, 'error') }, error));
    return (React.createElement("div", { className: cn(commonStyles.component, styles.component, className, {
            [commonStyles.hidden]: !params,
        }), "data-test-id": dataTestId },
        error ? renderError() : renderMessage(),
        React.createElement(ReactCanvasPatternLock, { ...restProps, ...params, ref: ref, rows: 3, cols: 3, justifyNodes: justifyNodes, extraBounds: extraBounds, hover: hover }),
        showForgotCodeBtn ? (React.createElement(ButtonMobile, { view: 'transparent', className: cn(commonStyles.forgotBtn, styles.forgotBtn), onClick: onForgotBtnClick, dataTestId: getDataTestId(dataTestId, 'forgot-code-btn') }, forgotCodeBtnText)) : (React.createElement("div", { className: cn(commonStyles.forgotBtn, styles.forgotBtn, {
                [styles.hiddenBtn]: Boolean(styles.hiddenBtn),
            }) }))));
});

export { BasePatternLock };

==> core-components-pattern-lock-v1-1.1.10.tgz: package/modern/components/base-pattern-lock/Component.js <==
import React, { forwardRef, useState, useEffect } from 'react';
import { ReactCanvasPatternLock } from 'react-canvas-pattern-lock';
import cn from 'classnames';
import { ButtonMobile } from '@alfalab/core-components-button/modern/mobile';
import { getDataTestId } from '@alfalab/core-components-shared/modern';
import { THEME_STATE, DEFAULT_EXTRA_BOUNDS, OBSERVE_OPTIONS, OBSERVABLE_TOKENS } from '../../consts.js';
import { getSizes, getTheme, getColorByToken, getDefaultObserveTarget } from '../../utils.js';

const commonStyles = {"component":"pattern-lock-v1__component_1r9m9","hidden":"pattern-lock-v1__hidden_1r9m9","message":"pattern-lock-v1__message_1r9m9","error":"pattern-lock-v1__error_1r9m9","forgotBtn":"pattern-lock-v1__forgotBtn_1r9m9"};
require('./index.css')

const BasePatternLock = forwardRef(({ observeTokens = false, observerParams = {}, justifyNodes = 'space-between', className, error, dataTestId, forgotCodeBtnText = 'Забыли код?', showForgotCodeBtn = false, onForgotBtnClick, extraBounds = DEFAULT_EXTRA_BOUNDS, message, messageClassName, hover, styles = {}, ...restProps }, ref) => {
    const [params, setParams] = useState();
    useEffect(() => {
        const { elementSizes, width, height } = getSizes();
        setParams({
            theme: getTheme(elementSizes),
            width,
            height,
        });
    }, []);
    useEffect(() => {
        let styleObserver = null;
        if (observeTokens) {
            const { options = OBSERVE_OPTIONS, getTarget = getDefaultObserveTarget } = observerParams;
            styleObserver = new MutationObserver(() => setParams((prevState) => {
                const { width, height, elementSizes } = getSizes();
                if (!prevState) {
                    return { theme: getTheme(elementSizes), width, height };
                }
                const prevBgColor = prevState.theme[THEME_STATE.INITIAL].colors.bg;
                const themeChanged = prevBgColor !== getColorByToken(OBSERVABLE_TOKENS.BG);
                if (themeChanged)
                    return { ...prevState, theme: getTheme(elementSizes) };
                return prevState;
            }));
            styleObserver.observe(getTarget(), options);
        }
        return () => styleObserver?.disconnect();
        // eslint-disable-next-line react-hooks/exhaustive-deps
    }, [observeTokens]);
    const renderMessage = () => (React.createElement("div", { className: cn(commonStyles.message, messageClassName), "data-test-id": getDataTestId(dataTestId, 'message') }, message));
    const renderError = () => (React.createElement("div", { className: cn(commonStyles.message, commonStyles.error, messageClassName), "data-test-id": getDataTestId(dataTestId, 'error') }, error));
    return (React.createElement("div", { className: cn(commonStyles.component, styles.component, className, {
            [commonStyles.hidden]: !params,
        }), "data-test-id": dataTestId },
        error ? renderError() : renderMessage(),
        React.createElement(ReactCanvasPatternLock, { ...restProps, ...params, ref: ref, rows: 3, cols: 3, justifyNodes: justifyNodes, extraBounds: extraBounds, hover: hover }),
        showForgotCodeBtn ? (React.createElement(ButtonMobile, { view: 'transparent', className: cn(commonStyles.forgotBtn, styles.forgotBtn), onClick: onForgotBtnClick, dataTestId: getDataTestId(dataTestId, 'forgot-code-btn') }, forgotCodeBtnText)) : (React.createElement("div", { className: cn(commonStyles.forgotBtn, styles.forgotBtn, {
                [styles.hiddenBtn]: Boolean(styles.hiddenBtn),
            }) }))));
});

export { BasePatternLock };
